package com.nisum.demo.blobStorage;

import com.microsoft.azure.functions.annotation.*;
import com.microsoft.azure.functions.*;
import org.bouncycastle.openpgp.PGPException;
import org.bouncycastle.openpgp.PGPPublicKey;
import org.bouncycastle.openpgp.PGPSecretKey;

import java.io.*;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.security.NoSuchAlgorithmException;
import java.security.NoSuchProviderException;
import java.security.SignatureException;
import java.util.PropertyResourceBundle;
import java.util.ResourceBundle;
import java.util.regex.Pattern;

/**
 * Azure Functions with Azure Blob trigger.
 */
public class BlobTriggerFunction {
    /**
     * This function will be invoked when a new or updated blob is detected at the specified path. The blob contents are provided as input to this function.
     */
    @FunctionName("BlobTriggerFunc")
    public void run(
        @BlobTrigger(name = "file", path = "test/{name}", dataType = "binary", connection = "AzureWebJobsStorage") byte[] content,
        @BindingName("name") String name,
        final ExecutionContext context
    ) throws IOException {
        ResourceBundle resourceBundle = new PropertyResourceBundle(new FileInputStream("/Users/eali/Projects/azure/myazurefunctionsdemo/src/main/resources/application.properties"));
        if (Pattern.matches("[a-z|A-Z]*.csv", name)) {
            String directoryPath = resourceBundle.getString("files.directory.path") + name;
            if (!Files.exists(Paths.get(directoryPath))) {
                Files.createFile(Paths.get(directoryPath));
            }

            try (FileOutputStream fileOutputStream = new FileOutputStream(directoryPath, true)) {
                fileOutputStream.write(content);
            }

            InputStream inputStreamSecretKey = new FileInputStream(resourceBundle.getString("gpg.keychain.secret.key"));
            InputStream inputStreamPublicKey = new FileInputStream(resourceBundle.getString("gpg.keychain.public.key"));
            char[] pass = {'n', 'i', 's', 'u', 'm', '1', '2', '3', '4'};

            // Writes data to the output stream
            OutputStream outbound = new FileOutputStream(resourceBundle.getString("encrypted.files.directory.path") + name.replaceFirst(".csv",".asc"));
            String inbound= resourceBundle.getString("files.directory.path") + name;

            try {
//            use it when using only public key
//            PGPPublicKey key = PGPUtils.readPublicKey(inputStream);

//            use it to get secret key when using public + private key
//            PGPSecretKey pgpSecretKey = PGPUtils.readSecretKey(inputStream);

//                for encryption
                PGPUtils.encryptAndSignFile(outbound, inbound, inputStreamPublicKey, inputStreamSecretKey, true, true, pass);
                context.getLogger().info("---File Encrypted---");


//                for decryption
//                InputStream fileToBeDecrypt = new FileInputStream(resourceBundle.getString("encrypted.files.directory.path") + name.replaceFirst(".csv", ".asc"));
//                OutputStream inboundN = new FileOutputStream(resourceBundle.getString("decrypted.files.directory.path"));
//                PGPUtils.decryptFile(fileToBeDecrypt, inboundN, inputStreamSecretKey, pass, inputStreamPublicKey);


            } catch (Exception e) {
                e.printStackTrace();
            }
            // Closes the output stream
        }

        context.getLogger().info("Java Blob trigger function processed a blob. Name: " + name + "\n  Size: " + content.length + " Bytes");
    }
}
