package com.nisum.demo.blobStorage;

import java.io.IOException;
import java.security.NoSuchProviderException;
import java.security.SignatureException;

import org.bouncycastle.openpgp.PGPException;

public abstract class DecryptService {

    /**
     * Decrypt the input file and move it to output folder.
     *
     * @param inputPath encrypted file path
     * @param outputPath destination file path
     * @param secretKeyPath secret key file path
     * @param partnerPublicKeyPath partner public key file path
     * @param passPhrase pass phrase use to generate secret key
     * @throws NoSuchProviderException thrown when security provider not found
     * @throws IOException throws when unable accessing file path.
     * @throws PGPException thrown when error performing PGP decryption
     * @throws SignatureException when error performing verification of signature
     */
    abstract void decrypt(String inputPath, String outputPath, String secretKeyPath, String partnerPublicKeyPath, String passPhrase)
            throws NoSuchProviderException, IOException, PGPException, SignatureException;

}
